const fetch = require('isomorphic-fetch');

/**
 * Wrapper for standard API calls
 *
 * provides error-checking, default options such as include credentials, no cache, etc
 * Validates response as JSON and returns JS object, or returns error with text of response
 *
 * @param url
 * @param options
 * @param cb
 */
function apiFetch(url, options, cb) {
    let defaultOptions = {
        credentials: 'include',
        method: 'POST',
        cache: 'no-cache'
    };

    let init = Object.assign({}, defaultOptions, options);

    // Switch method to GET if no data sent
    if(!('body' in init)) {
        init.method = 'GET';
    }

    // Start request
    fetch(url, init)
        .then(response => {
            // If response status OK, process data
            if(response.ok) {
                let contentType = response.headers.get("content-type");
                // Parse JSON data, pass into callback
                if(contentType && contentType.indexOf("application/json") !== -1) {
                    return response.json()
                        .then(data => {
                            cb(null, data);
                        });
                }
                else {
                    return response.text()
                        .then(text => {
                            cb({message: text}, {});
                        });
                }
            }
            // Response problem, throw error
            else {
                cb({message: response.status + ' ' + response.statusText}, {});
            }
        })
        .catch(error => {
            cb({message: error.message}, {});
        });
}

module.exports = apiFetch;